#
# spec file for package ffms2
#
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define libname lib%{name}
%define soname 4
Name:           ffms2
Version:        2.22
Release:        2.2
Summary:        Wrapper library around libffmpeg
License:        MIT
Group:          System/Libraries
Url:            https://github.com/FFMS/ffms2
Source:         https://github.com/FFMS/ffms2/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         ffms2-pkgconfig.patch
%if 0%{?suse_version} == 1110
BuildRequires:  gcc48-c++
%else
BuildRequires:  gcc-c++ >= 4.8
%endif
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FFmpegSource (usually known as FFMS or FFMS2) is a cross-platform wrapper
library around libffmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n ffmsindex
Summary:        Wrapper library around libffmpeg
Group:          Productivity/Multimedia/Other

%description -n ffmsindex
FFmpegSource (usually known as FFMS or FFMS2) is a cross-platform wrapper
library around libffmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n %{libname}-%{soname}
Summary:        Wrapper library around libffmpeg
Group:          System/Libraries

%description -n %{libname}-%{soname}
FFmpegSource (usually known as FFMS or FFMS2) is a cross-platform wrapper
library around libffmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n %{libname}-devel
Summary:        Wrapper library around libffmpeg
Group:          Development/Libraries/C and C++
Requires:       %{libname}-%{soname} = %{version}

%description -n %{libname}-devel
FFmpegSource (usually known as FFMS or FFMS2) is a cross-platform wrapper
library around libffmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%prep
%setup -q
%patch0 -p1
sed -i 's/\r$//' COPYING

%build
%if 0%{?suse_version} == 1110
export CXX=g++-4.8
%endif
%configure --docdir=%{_docdir}/%{libname}-devel \
           --disable-static --enable-shared

make %{?_smp_mflags} V=1

%install
%make_install V=1
rm %{buildroot}%{_libdir}/%{libname}.la

%post -n %{libname}-%{soname} -p /sbin/ldconfig
%postun -n %{libname}-%{soname} -p /sbin/ldconfig

%files -n ffmsindex
%defattr(0644, root, root, 0755)
%attr(0755,root,root) %{_bindir}/ffmsindex

%files -n %{libname}-%{soname}
%defattr(0644, root, root, 0755)
%doc COPYING
%{_libdir}/%{libname}.so.%{soname}*

%files -n %{libname}-devel
%defattr(0644, root, root, 0755)
%{_libdir}/%{libname}.so
%{_includedir}/ffms*
%{_libdir}/pkgconfig/%{name}.pc
%{_docdir}/%{libname}-devel

%changelog
* Sun May  1 2016 aloisio@gmx.com
- Update to 2.22
  * Fix possible off by 1 frame until first seek issue introduced
    in 2.21 (Myrsloik)
  * avisynth: Make FFMS2 a shorter alias for FFmpegSource2 to save
    some typing (Myrsloik)
  * avisynth: Moved all source functions in ffms2.avsi into the
    actual plugin (Myrsloik)
  * avisynth: Use 2.6 RC API and add output support for all new
    colorspaces (Myrsloik)
  * vapoursource: Fix swapped RGB channels bug introduced in
    2.21 (Myrsloik)
  * swscale: Drop pointless and slow bitexact flag from resizer
    settings (kodabb)
  * Add support for files with gaps between the audio packets
    (Plorkyeran)
  2.21:
  * Add missing constants for log levels (Myrsloik)
  * Fix bad decoder flush that discards the palette of raw video
    (Myrsloik)
  * Remove the SWScale function from Avisynth since SWScale is
    useless (Myrsloik)
  * Fix common framerate correction (Myrsloik)
  * vapoursource: The framerate and frame durations are now
    normalized (Myrsloik)
  * vapoursource: Add support for outputting the alpha channel
    too (Myrsloik)
  * vapoursource: Fix resizer selection so bicubic isn't always
    used (Myrsloik)
  * vapoursource: Set chroma location and full colorspace
    information (Myrsloik)
  * Add support for indexing files with more than 32 tracks and
    the possibility to skip indexing of video tracks (Myrsloik)
  * The Avisynth plugin now sets all per frame variables in all
    modes to avoid ugly and slow FFInfo() errors (Myrsloik)
  * vapoursource: Fix crash on single frame files (Myrsloik)
  * Remove the Matroska and Haali demuxers (qyot27, Plorkyeran)
  * Fix adjustments for positive audio delay (tophf)
  * Don't try to index video tracks in unsupported formats
    (Daemon404)
  * Don't use scientific notation in timecode files (Daemon404)
  * Fix utf8 support in FFVideoSource (nixxquality)
  * Improve handling of files where only some packets have
    timestamps (Plorkyeran)
  * Fix memory leaks in the VapourSynth error handling (Plorkyeran)
  2.20:
  * Add support for Opus in MKV when ffmpeg/libav are built with
    libopus (qyot27)
  * vapoursource: Provide _AbsoluteTime metadata (Daemon404)
  * Fix a pile of small things found by Coverity (Daemon404)
  * Add support for HEVC in MKV (qyot27)
  * Fix infinite loop on garbage data at the beginning of AAC
    files (Plorkyeran)
  * Deal with the never-ending bitrot from FFmpeg/Libav API changes
    (Daemon404, Plorkyeran)
  * Make indexes not arch-specific and trivially smaller (Plorkyeran)
  * Fix bug where the first b-frame was replaced with the frame
    before it with open-gop h.264 (Plorkyeran)
  * Fix seeking issues with open-gop h.264 (Plorkyeran)
  * Fix corruption when seeking in interlaced h.264 (Plorkyeran)
  * Add support for multiple frames per audio packet as FFmpeg seems
    to have started doing that (Plorkyeran)
  * Fix seeking in Y4M files (Plorkyeran)
  * Fix dumping audio while indexing files
  * Add support for Matroska files with extremely large CodecPrivate
    sections
  * Speed up indexing Matroska files a bit
- Bumped soname to 4
- Switched to ffmpeg 3.0
* Wed Feb 17 2016 olaf@aepfle.de
- Remove unused Requires from pkgconfig file
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Apr 21 2014 i@margueirte.su
- update version 2.19.2
- drop patch: ffms2-2.17-ffmpeg_011.patch, upstreamed
- drop patch: ffms2-2.17-ffmpeg_10.patch, upstreamed
- drop patch: ffms2-2.17-ffmpeg_20.patch, upstream fixed
* Tue Jul 30 2013 i@margueirte.su
- Fix build with ffmpeg 2.0
* Fri Nov 16 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 1.0
- Adapt the file list to be compatible with old RPMs
* Sun May 27 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Fri Feb 10 2012 reddwarf@opensuse.org
- Update to 2.1.7
* Sat Oct 29 2011 reddwarf@opensuse.org
- First version
